class MalformedRegionException(Exception):
    pass


class SPIUnavailableException(Exception):
    pass


class ECCMalfunctionException(Exception):
    pass


class GatewayMFRFileNotFoundException(Exception):
    pass


class MinerFailedToFetchMacAddress(Exception):
    pass
